@@ -1,6 +1,6 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2012 Luca Falavigna
+# Copyright (C) 2007-2013 Luca Falavigna
 # Copyright (C) 2010 Alessio Treglia
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
@@ -57,6 +57,10 @@ class Build:
         self.lockfile.acquire()
 
     def build(self):
+        if self.full:
+            self.w(_('Full build routine launched'), 3)
+        else:
+            self.w(_('Simple build routine launched'), 3)
         if self.dscfile:
             self.files.add(self.dscfile)
         self.parse_distribution_options()
@@ -64,8 +68,12 @@ class Build:
             self.remove_files()
             self.e(_('Distribution %s is disabled' % self.distribution))
         self.fetch_missing_files()
-        self.setup_pbuilder()
-        self.build_package()
+        try:
+            self.setup_pbuilder()
+        except RuntimeError:
+            self.remove_files()
+        else:
+            self.build_package()
 
     def build_package(self):
         mod = Module((self.opts, self.rtopts, self.conffile))
@@ -77,6 +85,7 @@ class Build:
             os.mkdir(builddir)
         if self.uploader:
             uploader_email = self.uploader[1]
+        self.w(_('Pre-build hooks launched'), 3)
         mod.execute_hook('pre_build', {'cfg': self.configfile,
                                        'directory': self.buildpath,
                                        'distribution': self.distribution,
@@ -84,6 +93,7 @@ class Build:
                                        'opts': self.opts,
                                        'package': packageversion,
                                        'uploader': uploader_email})
+        self.w(_('Pre-build hooks finished'), 3)
         builder = self.opts.get('default', 'builder')
         if builder == 'cowbuilder':
             base = '--basepath'
@@ -94,18 +104,23 @@ class Build:
                             self.get_changelog_versions(),
                             self.get_orig_tarball()))
         with open(os.devnull, 'w') as fd:
-            call([builder, '--build', '--override-config',
-                 base, '%s/%s' % (self.buildpath, self.distribution),
-                 '--logfile', '%s/pool/%s/%s.buildlog' %
-                 (self.buildpath, packageversion, packageversion),
-                 '--buildplace', '%s/build' % self.buildpath,
-                 '--buildresult', '%s/pool/%s' %
-                 (self.buildpath, packageversion),
-                 '--aptcache', '%s/aptcache' % self.buildpath,
-                 '--debbuildopts', '%s' % debopts,
-                 '--hookdir', self.opts.get('default', 'pbuilderhooks'),
-                 '--configfile', self.configfile, self.dscfile],
-                 stdout=fd, stderr=fd)
+            try:
+                self.w(_('Launching %s') % builder , 2)
+                call([builder, '--build', '--override-config',
+                     base, '%s/%s' % (self.buildpath, self.distribution),
+                     '--logfile', '%s/pool/%s/%s.buildlog' %
+                     (self.buildpath, packageversion, packageversion),
+                     '--buildplace', '%s/build' % self.buildpath,
+                     '--buildresult', '%s/pool/%s' %
+                     (self.buildpath, packageversion),
+                     '--aptcache', '%s/aptcache' % self.buildpath,
+                     '--debbuildopts', '%s' % debopts,
+                     '--hookdir', self.opts.get('default', 'pbuilderhooks'),
+                     '--configfile', self.configfile, self.dscfile],
+                     stdout=fd, stderr=fd)
+            except OSError:
+                self.w(_('Unable to launch %s') % builder)
+        self.w(_('Post-build hooks launched'), 3)
         mod.execute_hook('post_build', {'cfg': self.configfile,
                                         'directory': self.buildpath,
                                         'distribution': self.distribution,
@@ -113,7 +128,9 @@ class Build:
                                         'opts': self.opts,
                                         'package': packageversion,
                                         'uploader': uploader_email})
+        self.w(_('Post-build hooks finished'), 3)
         self.remove_files()
+        self.w(_('Build of %s complete') % os.path.basename(self.dscfile))
 
     def fetch_missing_files(self):
         filename = self.dscfile if self.dscfile else self.package
@@ -123,6 +140,9 @@ class Build:
                 if filename.endswith('.dsc'):
                     self.dscfile = filename
                     break
+        if not self.dscfile:
+            self.remove_files()
+            self.e(_('Bad .changes file: %s') % self.package)
         with open(self.dscfile, 'r') as fd:
             data = fd.read()
         for entry in findall('\s\w{32}\s\d+\s(\S+)', data):
@@ -133,6 +153,7 @@ class Build:
                                        findall('^lib\S|^\S', packagename)[0],
                                        packagename, entry))
                     try:
+                        self.w(_('Downloading missing %s' % entry), 2)
                         data = urlopen(request).read()
                         break
                     except (HTTPError, URLError):
@@ -194,25 +215,32 @@ class Build:
             else:
                 if isinstance(mapper, dict):
                     if self.distribution in mapper:
+                        self.w(_('%(mapped)s mapped as %(mapper)s') % 
+                               {'mapped': self.distribution,
+                               'mapper': mapper[self.distribution]}, 3)
                         self.distribution = mapper[self.distribution]
 
     def needs_update(self):
         if not os.path.exists(os.path.join(self.buildpath, 'gpg')):
             os.mkdir(os.path.join(self.buildpath, 'gpg'))
-        gpgfile = os.path.join(self.buildpath, 'gpg', self.distribution)
+        gpgfile = os.path.join(self.buildpath, 'gpg',
+                               self.distopts['distribution'])
         if not os.path.exists(gpgfile):
             self.cmd = 'create'
+            self.w(_('Chroot must be created'), 2)
             return
         if self.distribution in self.runtime_option('alwaysupdate'):
             self.cmd = 'update'
+            self.w(_('Chroot must be updated'), 2)
             return
         uri = '%s/dists/%s/Release.gpg' % (self.distopts['mirror'],
-                                           self.distribution)
+                                           self.distopts['distribution'])
         try:
             remote = urlopen(uri).read()
-        except HTTPError:
+        except (HTTPError, URLError):
             self.w(_('Unable to fetch %s') % uri)
             self.cmd = update
+            self.w(_('Chroot must be updated'), 2)
             return
         remote_sha = sha256()
         gpgfile_sha = sha256()
@@ -222,9 +250,11 @@ class Build:
                 gpgfile_sha.update(fd.read())
         except OSError:
             self.cmd = 'create'
+            self.w(_('Chroot must be created'), 2)
             return
         if remote_sha.digest() != gpgfile_sha.digest():
             self.cmd = 'update'
+            self.w(_('Chroot must be updated'), 2)
 
     def parse_distribution_options(self):
         conf = {'components': ('[^#]?COMPONENTS="?(.*[^"])"?\n', 'COMPONENTS'),
@@ -247,10 +277,7 @@ class Build:
             except IndexError:
                 self.e(_('Bad .changes file: %s') % self.packagepath)
             self.distribution = distro.lower()
-            self.map_distribution()
-            self.distopts['distribution'] = self.distribution
-        else:
-            self.map_distribution()
+        self.map_distribution()
         self.buildpath = os.path.join(self.packagedir, self.distribution)
         self.configfile = os.path.join(self.opts.get('default', 'configdir'),
                                        self.distribution)
@@ -258,6 +285,7 @@ class Build:
             with open(self.configfile) as fd:
                 data = fd.read()
         except IOError:
+            self.remove_files()
             self.log.e(_('Unable to open %s') % self.configfile)
         for elem in conf.keys():
             try:
@@ -292,24 +320,34 @@ class Build:
             if not os.path.exists(repo_file):
                 with open(os.path.splitext(repo_file)[0], 'w') as fd:
                     pass
-        call(['gzip', '-9', '-f',
-              os.path.join(self.buildpath, 'pool', 'Packages')], stderr=PIPE)
+        try:
+            call(['gzip', '-9', '-f', os.path.join(self.buildpath, 'pool',
+                                                   'Packages')], stderr=PIPE)
+        except OSError:
+            self.w(_('Unable to launch %s') % 'gzip')
         builder = self.opts.get('default', 'builder')
         if builder == 'cowbuilder':
             base = '--basepath'
         else:
             base = '--basetgz'
         with open(os.devnull, 'w') as fd:
-            while call([builder, '--%s' % self.cmd, '--override-config',
-                       base, '%s/%s' % (self.buildpath, self.distribution),
-                       '--buildplace', '%s/build' % self.buildpath,
-                       '--aptcache', '%s/aptcache' % self.buildpath,
-                       '--logfile', '%s/logs/%s.%s' %
-                       (self.buildpath, self.cmd, strftime('%Y%m%d_%H%M%S')),
-                       '--configfile', '%s' % self.configfile],
-                       stdout=fd, stderr=fd):
-                self.w(_('%(builder)s %(cmd)s failed') %
-                       {'builder': builder, 'cmd': self.cmd})
+            try:
+                self.w(_('Launching %(builder)s %(cmd)s')
+                       % {'builder': builder, 'cmd': self.cmd} , 2)
+                if call([builder, '--%s' % self.cmd, '--override-config',
+                        base, '%s/%s' % (self.buildpath, self.distribution),
+                        '--buildplace', '%s/build' % self.buildpath,
+                        '--aptcache', '%s/aptcache' % self.buildpath,
+                        '--logfile', '%s/logs/%s.%s' %
+                        (self.buildpath, self.cmd, strftime('%Y%m%d_%H%M%S')),
+                        '--configfile', '%s' % self.configfile],
+                        stdout=fd, stderr=fd):
+                    self.release_lock()
+                    self.e(_('%(builder)s %(cmd)s failed') %
+                           {'builder': builder, 'cmd': self.cmd})
+            except OSError:
+                self.release_lock()
+                self.e(_('Unable to launch %s') % builder)
 
     def release_lock(self):
         self.lockfile.release()
@@ -339,7 +377,7 @@ class Build:
                                                self.distopts['distribution'])
             try:
                 remote = urlopen(uri).read()
-            except HTTPError:
+            except (HTTPError, URLError):
                 self.release_lock()
                 self.e(_('Unable to fetch %s') % uri)
             with open(gpgfile, 'w') as fd:
